# UCSC CSE 40

Materials for UCSC's CSE 40 course taught by Dr. Lise Getoor and managed by the [LINQS lab](https://linqs.org/).
This package is available on PyPi at [ucsc-cse40](https://pypi.org/project/ucsc-cse40/).

## Dependencies

This package is meant to be the sole direct dependency for CSE 40 students.
Instead of specifying each dependency for students, this package defines the necessary dependencies to be installed along with it.
So if you install this package (e.g. via pip), then it will also install all the necessary Python package dependencies for the course.

## Working with the Autograder

All interfacing with the autograder is done via the [autograder-py](https://pypi.org/project/autograder-py/) package.
You should refer to [the documentation](https://github.com/eriq-augustine/autograder-py) for information on how to use it.
